@@ -13,9 +13,9 @@ from shutil import copy2
 from email.utils import formatdate
 from enum import Enum
 
-__version__ = "2.202501"
+__version__ = "2.202502"
 __dhlib__ = "/usr/share/debhelper/dh_make"
-policy_version = "4.7.1"
+policy_version = "4.7.2"
 
 
 def check_dhlib_path():
@@ -127,11 +127,11 @@ def process_docs(python, docs_package, package_name):
     docfiles = []
 
     if python:
-        filename = "python-{}-doc.docs".format(package_name)
+        filename = "python-{}-doc.docs.ex".format(package_name)
     elif docs_package:
-        filename = "{}.docs".format(package_name)
+        filename = "{}.docs.ex".format(package_name)
     else:
-        filename = "{}-docs.docs".format(package_name)
+        filename = "{}-docs.docs.ex".format(package_name)
 
     if os.path.isfile(filename):
         print("debian/{} file already exists, skipping.\n".format(filename))
@@ -176,11 +176,11 @@ def process_infos(python, docs_package, package_name):
     infos = []
 
     if python:
-        filename = "python-{}-doc.info".format(package_name)
+        filename = "python-{}-doc.info.ex".format(package_name)
     elif docs_package:
-        filename = "{}.info".format(package_name)
+        filename = "{}.info.ex".format(package_name)
     else:
-        filename = "{}-docs.info".format(package_name)
+        filename = "{}-docs.info.ex".format(package_name)
 
     if os.path.isfile(filename):
         print("debian/{} already exists, skipping.\n".format(filename))
@@ -963,8 +963,8 @@ def do_debianize(args, subs):
         # native packages don't have a watch file #806672
         if args.native:
             os.unlink("watch.ex")
-            os.unlink("upstream/metadata.ex")
-            os.rmdir("upstream")
+            os.unlink("upstream.ex/metadata.ex")
+            os.rmdir("upstream.ex")
 
         # Files specific to package classes
         process_dhlib(args, subs_func, "debian" + args.package_class.value)
